@@ -7,12 +7,31 @@ list see the documentation:
 https://www.sphinx-doc.org/en/master/usage/configuration.html
 """
 
+import dataclasses
 import os
 import shutil
 import subprocess
 import sys
+from typing import Union
 
+import sphinxcontrib.bibtex.plugin
 from pkg_resources import get_distribution
+from pybtex.database import Entry
+from pybtex.plugin import register_plugin
+from pybtex.richtext import Tag, Text
+from pybtex.style.formatting.unsrt import Style as UnsrtStyle
+from pybtex.style.template import (
+    FieldIsMissing,
+    Node,
+    _format_list,
+    field,
+    href,
+    join,
+    node,
+    sentence,
+    words,
+)
+from sphinxcontrib.bibtex.style.referencing import BracketStyle
 
 # -- Project information -----------------------------------------------------
 project = "AmpForm"
@@ -93,6 +112,7 @@ autodoc_default_options = {
             "default_assumptions",
             "doit",
             "evaluate",
+            "is_commutative",
         ]
     ),
     "members": True,
@@ -109,7 +129,9 @@ autodoc_default_options = {
 autodoc_insert_signature_linebreaks = False
 graphviz_output_format = "svg"
 html_copy_source = True  # needed for download notebook button
-html_css_files = []
+html_css_files = [
+    "custom.css",
+]
 if autodoc_insert_signature_linebreaks:
     html_css_files.append("linebreaks-api.css")
 html_favicon = "_static/favicon.ico"
@@ -194,7 +216,6 @@ bibtex_bibfiles = ["bibliography.bib"]
 suppress_warnings = [
     "myst.domains",
 ]
-bibtex_reference_style = "author_year_no_comma"
 
 # Settings for copybutton
 copybutton_prompt_is_regexp = True
@@ -245,7 +266,7 @@ myst_substitutions = {
     "run_interactive": f"""
 ```{{margin}}
 Run this notebook [on Binder]({BINDER_LINK}) or
-{{ref}}`locally on Jupyter Lab <pwa:develop:Jupyter Notebooks>` to
+{{ref}}`locally on Jupyter Lab <compwa-org:develop:Jupyter Notebooks>` to
 interactively modify the parameters.
 ```
 """
@@ -260,49 +281,6 @@ thebe_config = {
 
 
 # Specify bibliography style
-import dataclasses
-from typing import Union
-
-import sphinxcontrib.bibtex.plugin
-from pybtex.database import Entry
-from pybtex.plugin import register_plugin
-from pybtex.richtext import Tag, Text
-from pybtex.style.formatting.unsrt import Style as UnsrtStyle
-from pybtex.style.template import (
-    FieldIsMissing,
-    Node,
-    _format_list,
-    field,
-    href,
-    join,
-    node,
-    sentence,
-    words,
-)
-from sphinxcontrib.bibtex.style.referencing import BracketStyle
-from sphinxcontrib.bibtex.style.referencing.author_year import (
-    AuthorYearReferenceStyle,
-)
-
-no_brackets = BracketStyle(
-    left="",
-    right="",
-)
-
-
-@dataclasses.dataclass
-class NoCommaReferenceStyle(AuthorYearReferenceStyle):
-    author_year_sep: Union["BaseText", str] = " "
-    bracket_parenthetical: BracketStyle = no_brackets
-
-
-sphinxcontrib.bibtex.plugin.register_plugin(
-    "sphinxcontrib.bibtex.style.referencing",
-    "author_year_no_comma",
-    NoCommaReferenceStyle,
-)
-
-
 @node
 def et_al(children, data, sep="", sep2=None, last_sep=None):
     if sep2 is None:
